@@ -3,16 +3,23 @@
 
 #include "about.h"
 #include "help.h"
+#include "settings.h"
 
 #include <QProcess>
 #include <QtCore/QCoreApplication>
 #include <QDesktopServices>
+#include <QShortcut>
 #include <QUrl>
+#include <QSettings>
+
+
+
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow),
       about(0),
       help(0),
+      m_settings(0),
       m_process(new QProcess(this))
 
 {
@@ -21,12 +28,19 @@ MainWindow::MainWindow(QWidget *parent)
     setAttribute(Qt::WA_Maemo5StackedWindow);
     about = new About(this);
     help = new Help(this);
+    m_settings = new Settings(this);
+
+
+    // For Connecting Keyboard Buttons
+      connectSignals();
+
 }
 
 MainWindow::~MainWindow()
 {
     if (about) delete (about);
     if (help) delete (help);
+    if (m_settings) delete (m_settings);
     delete ui;
 }
 
@@ -84,6 +98,20 @@ void MainWindow::showExpanded()
 #endif
 }
 
+//---------------------------------------------------------//
+// Keyboard Button Signals - remember to include QShortcut
+void MainWindow::connectSignals()
+{
+
+// Keyboard Key Signals
+  connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonStart_clicked()));
+}
+
+// End of Keyboard Signals
+
+//--------------------------------------------------------//
+
+
 void MainWindow::on_pushButtonStart_clicked()
 {
     m_process->start("sh opt/tenminutecore/script/tenminutecore.sh");
@@ -98,3 +126,22 @@ void MainWindow::on_actionHelp_triggered()
 {
     help->show();
 }
+
+void MainWindow::on_actionSettings_triggered()
+{
+    m_settings->show();
+}
+
+void MainWindow::on_actionSecureDevice_triggered()
+{
+      QSettings settings;
+      if ( settings.value("SecureSettingSilent","true").toString()=="true" )
+      {
+          m_process->start("sh opt/tenminutecore/script/lkscsl.sh");
+      }
+      else
+      {
+          m_process->start("sh opt/tenminutecore/script/lksc.sh");
+      }
+}
+
