@@ -6,6 +6,7 @@
 
 class About;
 class Help;
+class Settings;
 
 namespace Ui {
     class MainWindow;
@@ -30,16 +31,26 @@ public:
     void showExpanded();
 
 private slots:
+
+    // For Connecting Keyboard buttons
+    void connectSignals();
+
+    //Button Slots
     void on_pushButtonStart_clicked();
 
     void on_actionAbout_triggered();
 
     void on_actionHelp_triggered();
 
+    void on_actionSettings_triggered();
+
+    void on_actionSecureDevice_triggered();
+
 private:
     Ui::MainWindow *ui;
     About *about;
     Help *help;
+    Settings *m_settings;
     QProcess *m_process;
 };
 
